==> haskell-configfile-1.1.4-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-JYaR38ozDfnGDOcat7K6XD
key: ConfigFile-1.1.4-JYaR38ozDfnGDOcat7K6XD
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: d9573ef03964901398c7bea161cf52f8
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.4.3/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-JYaR38ozDfnGDOcat7K6XD
depends:
    MissingH-1.4.0.1-DuwhVGLZFn5LS7gfP7PQTa base-4.11.1.0
    containers-0.5.11.0 mtl-2.2.2 parsec-3.1.13.0
abi-depends: MissingH-1.4.0.1-DuwhVGLZFn5LS7gfP7PQTa=83a1f27ce0688ae445a98c4f8dbe7849
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configfile-1.1.4-41-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ConfigFile
version: 1.1.4
id: ConfigFile-1.1.4-DPlGaVvzWbzHyLjBdbh9UF
key: ConfigFile-1.1.4-DPlGaVvzWbzHyLjBdbh9UF
license: BSD-3-Clause
copyright: Copyright (c) 2004-2014 John Goerzen
maintainer: John Goerzen <jgoerzen@complete.org>
author: John Goerzen
stability: Stable
homepage: http://software.complete.org/configfile
synopsis: Configuration file reading & writing
description:
    Parser and writer for handling sectioned config files in
    Haskell.
    .
    The ConfigFile module works with configuration files in a standard
    format that is easy for the user to edit, easy for the programmer
    to work with, yet remains powerful and flexible.  It is inspired by,
    and compatible with, Python'\''s ConfigParser module.  It uses files
    that resemble Windows .INI-style files, but with numerous
    improvements.
    .
    ConfigFile provides simple calls to both read and write config files.
    It'\''s possible to make a config file parsable by this module,
    the Unix shell, and make.
category: Parsing
abi: cf9b7f3feab67c0ac1db61c13c8077c2
exposed: True
exposed-modules:
    Data.ConfigFile Data.ConfigFile.Monadic Data.ConfigFile.Parser
    Data.ConfigFile.Types
hidden-modules: Data.ConfigFile.Lexer
import-dirs: /usr/lib/ghc-8.4.3/site-local/ConfigFile-1.1.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/ConfigFile-1.1.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/ConfigFile-1.1.4
hs-libraries: HSConfigFile-1.1.4-DPlGaVvzWbzHyLjBdbh9UF
depends:
    MissingH-1.4.1.0-2k2reSH2SdKKj1RsoyEJMU base-4.11.1.0
    containers-0.5.11.0 mtl-2.2.2 parsec-3.1.13.0
abi-depends: MissingH-1.4.1.0-2k2reSH2SdKKj1RsoyEJMU=5b5f7a802652bc187c35eaf77c269245
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parsec-3.1.13.0=a963888603f65e0a8f63f07fffd516d6
haddock-interfaces: /usr/share/doc/haskell-configfile/html/ConfigFile.haddock
haddock-html: /usr/share/doc/haskell-configfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
